Function std::intrinsics::breakpointUnstable
[-] [+]
[src]
pub unsafe extern "rust-intrinsic" fn breakpoint()
Executes a breakpoint trap, for inspection by a debugger.
pub unsafe extern "rust-intrinsic" fn breakpoint()
Executes a breakpoint trap, for inspection by a debugger.
Prefix searches with a type followed by a colon (e.g.
fn:) to restrict the search to a given type.
Accepted types are: fn, mod,
struct, enum,
trait, typedef (or
tdef).